<template>
  <el-dialog
    title="设置点位"
    :visible.sync="showMapDia"
    fullscreen
    :before-close="handleClose"
    custom-class="map-location-dialog"
  >
    <div class="position-info">
      <div>
        <span class="position-inner">经度：{{ currentPoint.lgtd }}</span>
        <span class="position-inner">纬度：{{ currentPoint.lttd }}</span>
        <span class="position-inner">所属区域：{{ currentPoint.areaId }}</span>
      </div>
      <div>
        <el-button type="primary" @click="getPoint" size="mini"
          >设置点位
        </el-button>
        <i class="el-icon-warning"></i>
        <span class="tips"
          >提示：先点击设置点位按钮，再点击地图选择点位，获取点位数据。再次获取点位数据需重复此操作。</span
        >
      </div>
    </div>
    <div class="map-container">
      <iframe
        class="map-container-iframe"
        ref="windowiframe"
        :src="src"
        frameborder="0"
        scrolling="auto"
        align="absmiddle"
      />
    </div>
    <span slot="footer" class="dialog-footer">
      <el-button @click="showMapDia = false">取 消</el-button>
      <el-button type="primary" @click="handleSure">确 定</el-button>
    </span>
  </el-dialog>
</template>

<script>
import Iframe from '@/views/Manage/components/Iframe.vue'
import equipmentManage from '@/api/device/equipmentManage.js'
export default {
  name: 'EquipmentMap',
  components: {
    Iframe,
  },
  data() {
    return {
      type: '',
      currentPoint: {
        id: '',
        lttd: '',
        lgtd: '',
        areaId: '',
      },
      timer: null,
      showMapDia: false,
      // src: '/gisapi/station-n-map/#/DeviceManagerGisView?mapMode=2D', //测试地址
      src:
        window.context.map + '/station-n-map/#/DeviceManagerGisView?mapMode=2D',
      areaId: '',
    }
  },
  mounted() {
    this.timer = setInterval(() => {
      if (
        this.$refs.windowiframe &&
        this.$refs.windowiframe.contentWindow.deviceGisFunction
      ) {
        const layerList = []
        // console.log(
        //     '图层',
        //     this.$refs.windowiframe.contentWindow.publicLayerData
        // )
        this.$refs.windowiframe.contentWindow.deviceGisFunction.layerVisible(
          layerList
        )
        this.clearPoints()
        this.setDefaultPoints()
        clearInterval(this.timer)
      }
    }, 1000)
  },
  methods: {
    handleOpen(data, type = 'detail') {
      this.type = type
      this.currentPoint = {
        id: data.id ? data.id : '',
        lttd: data.lttd ? data.lttd : '',
        lgtd: data.lgtd ? data.lgtd : '',
        areaId: data?.areaCode || '',
      }
      if (
        this.$refs.windowiframe &&
        this.$refs.windowiframe.contentWindow.deviceGisFunction
      ) {
        this.clearPoints()
        this.setDefaultPoints()
      }
      this.showMapDia = true
    },
    setDefaultPoints() {
      this.$nextTick(() => {
        if (this.currentPoint.lttd && this.currentPoint.lgtd) {
          let points = [
            {
              point: [
                parseFloat(this.currentPoint.lgtd),
                parseFloat(this.currentPoint.lttd),
              ],
              areaCode: this.currentPoint?.areaId || '',
            },
          ]
          if (
            this.$refs.windowiframe &&
            this.$refs.windowiframe.contentWindow.deviceGisFunction
          ) {
            this.$refs.windowiframe.contentWindow.deviceGisFunction.clearCustomPoints()
            // 打点
            this.$refs.windowiframe.contentWindow.deviceGisFunction.addCustomPoints(
              points
            )
            // 移动到对应区域
            this.$refs.windowiframe.contentWindow.deviceGisFunction.flyToPoints(
              points
            )
          }
        }
      })
    },
    handleSure() {
      if (this.type === 'update') {
        this.$confirm('确定修改点位信息并保存吗？', '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning',
        }).then(() => {
          let data = JSON.parse(JSON.stringify(this.currentPoint))
          data.lat = data.lgtd
          data.lat = data.lgtd
          data.areaCode = data.areaId
          equipmentManage.pointUpdate(data, (res) => {
            if (res.state) {
              this.$message.success('修改保存成功！')
              this.showMapDia = false
              this.$emit('getPosition', this.currentPoint)
            }
          })
        })
      } else {
        this.showMapDia = false
        this.$emit('getPosition', this.currentPoint)
      }
    },
    handleClose() {
      this.showMapDia = false
    },
    getPoint() {
      this.$nextTick(() => {
        if (
          this.$refs.windowiframe &&
          this.$refs.windowiframe.contentWindow.deviceGisFunction
        ) {
          this.clearPoints()
          this.$refs.windowiframe.contentWindow.deviceGisFunction
            .pickPoint()
            .then((p) => {
              console.log(p)

              this.setPositionInfo(p)
            })
        }
      })
    },
    setPositionInfo(position) {
      this.currentPoint.lttd = position.position[1]
      this.currentPoint.lgtd = position.position[0]
      this.currentPoint.areaId = position.areaCode
    },
    clearPoints() {
      this.$nextTick(() => {
        if (
          this.$refs.windowiframe &&
          this.$refs.windowiframe.contentWindow.deviceGisFunction
        ) {
          this.$refs.windowiframe.contentWindow.deviceGisFunction.clearCustomPoints()
          this.$refs.windowiframe.contentWindow.deviceGisFunction.clearPoint()
        }
      })
    },
  },
}
</script>

<style scoped lang="scss">
::v-deep .map-location-dialog.el-dialog .el-dialog__body {
    height: calc(100% - 120px);
    padding: 0 !important;
    box-sizing: border-box;
}

::v-deep .map-location-dialog.el-dialog .el-dialog__header {
    height: 60px;
    box-sizing: border-box;
}

::v-deep .map-location-dialog.el-dialog .el-dialog__footer {
    height: 52px;
    box-sizing: border-box;
}

.position-info {
    height: 76px;
    width: 100%;
    padding: 0 20px;
    text-align: left;
    box-sizing: border-box;
}

.position-title {
    font-size: 16px;
    font-weight: bold;
}

.position-inner {
    display: inline-block;
    min-width: 200px;
    padding-top: 6px;
    padding-bottom: 4px;
}

.map-container {
    width: 100%;
    height: calc(100% - 76px);
    text-align: center;
}

.map-container-iframe {
    width: 100%;
    height: 100%;
}

.el-icon-warning {
    color: #f53333;
    margin-left: 10px;
}

.tips {
    color: #f53333;
}
</style>
